controllers

package
v0.18.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 1, 2025 License: Apache-2.0 Imports: 25 Imported by: 0

Documentation

Index

Constants

const (
	// FinalizerAnnotation annotation string appended on finalizer slice.
	FinalizerAnnotation = "finalizer.operator.shipwright.io"

	// Ready object is providing service.
	ConditionReady = "Ready"

	// UseManagedWebhookCerts is an env Var that controls wether we install the webhook certs
	UseManagedWebhookCerts = "USE_MANAGED_WEBHOOK_CERTS"

	CertManagerInjectAnnotationKey = "cert-manager.io/inject-ca-from"

	CertManagerInjectAnnotationValueTemplate = "%s/shipwright-build-webhook-cert"
)

Variables

This section is empty.

Functions

func NoRequeue

func NoRequeue() (ctrl.Result, error)

NoRequeue all done, the object does not need reconciliation anymore.

func Requeue

func Requeue() (ctrl.Result, error)

Requeue triggers a object requeue.

func RequeueOnError

func RequeueOnError(err error) (ctrl.Result, error)

RequeueOnError triggers requeue when error is not nil.

func RequeueWithError

func RequeueWithError(err error) (ctrl.Result, error)

RequeueWithError triggers a object requeue because the informed error happend.

Types

type ShipwrightBuildReconciler

type ShipwrightBuildReconciler struct {
	client.Client        // controller kubernetes client
	CRDClient            crdclientv1.ApiextensionsV1Interface
	TektonOperatorClient tektonoperatorv1alpha1client.OperatorV1alpha1Interface

	Logger                logr.Logger           // decorated logger
	Scheme                *runtime.Scheme       // runtime scheme
	Manifest              manifestival.Manifest // release manifests render
	TektonManifest        manifestival.Manifest // Tekton release manifest render
	BuildStrategyManifest manifestival.Manifest // Build strategies manifest to render
}

ShipwrightBuildReconciler reconciles a ShipwrightBuild object

func (*ShipwrightBuildReconciler) Reconcile

Reconcile performs the resource reconciliation steps to deploy or remove Shipwright Build instances. When deletion-timestamp is found, the removal of the previously deploy resources is executed, otherwise the regular deploy workflow takes place.

func (*ShipwrightBuildReconciler) SetupWithManager

func (r *ShipwrightBuildReconciler) SetupWithManager(mgr ctrl.Manager) error

SetupWithManager sets up the controller with the Manager, by instantiating Manifestival and setting up watch and predicate rules for ShipwrightBuild objects.

type TektonCheckResult added in v0.17.0

type TektonCheckResult struct {
	IsReady        bool
	ConditionToSet *metav1.Condition
	Err            error
}

Jump to